@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-LcdProc
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2013-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -34,7 +34,7 @@ use warnings;
 # 3/ Write the resulting LCDd model
 
 use Config::Model 2.076;
-use Config::Model::Itself 2.001;    # to create the model
+use Config::Model::Itself 2.005;    # to create the model
 use Config::Model::Backend::IniFile;
 
 use 5.010;
@@ -42,11 +42,6 @@ use IO::File;
 use IO::String;
 use Getopt::Long;
 
-# initialise logs for Config;:Model
-use Log::Log4perl qw(:easy);
-my $log4perl_user_conf_file = $ENV{HOME} . '/.log4config-model';
-Log::Log4perl::init($log4perl_user_conf_file);
-
 say "Building lcdproc model from upstream LCDd.conf file..." ;
 
 my $verbose = 0;
@@ -329,8 +324,9 @@ foreach my $ini_class (@ini_classes) {
             type=warped_node 
             config_class_name="LCDd::$ini_class"
             level=hidden
-            follow:selected="- server Driver"
-            rules:"\$selected.is_set('$ini_class')"
+            warp
+              follow:selected="- server Driver"
+              rules:"\$selected.is_set('$ini_class')"
                 level=normal
         !;
     }
